nicfit.console package
======================

Submodules
----------

nicfit.console.ansi module
--------------------------

.. automodule:: nicfit.console.ansi
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nicfit.console
    :members:
    :undoc-members:
    :show-inheritance:
